==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/SERVICECODESUPPLIERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour SERVICECODESUPPLIERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="SERVICECODESUPPLIERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERVICEPROBLEMID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SERVICECODESUPPLIERID_Type", propOrder = {
    "serviceproblemid",
    "supplierid"
})
public class SERVICECODESUPPLIERID_Type {

    @XmlElement(name = "SERVICEPROBLEMID", required = true)
    protected SERVICEPROBLEMID_Type serviceproblemid;
    @XmlElement(name = "SUPPLIERID", required = true)
    protected SUPPLIERID_Type supplierid;

    /**
     * Obtient la valeur de la propriété serviceproblemid.
     * 
     * @return
     *     possible object is
     *     {@link SERVICEPROBLEMID_Type }
     *     
     */
    public SERVICEPROBLEMID_Type getSERVICEPROBLEMID() {
        return serviceproblemid;
    }

    /**
     * Définit la valeur de la propriété serviceproblemid.
     * 
     * @param value
     *     allowed object is
     *     {@link SERVICEPROBLEMID_Type }
     *     
     */
    public void setSERVICEPROBLEMID(SERVICEPROBLEMID_Type value) {
        this.serviceproblemid = value;
    }

    /**
     * Obtient la valeur de la propriété supplierid.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getSUPPLIERID() {
        return supplierid;
    }

    /**
     * Définit la valeur de la propriété supplierid.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setSUPPLIERID(SUPPLIERID_Type value) {
        this.supplierid = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/SERVICECODESUPPLIERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SERVICECODESUPPLIERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SERVICECODESUPPLIERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERVICEPROBLEMID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SERVICECODESUPPLIERID_Type", propOrder = {
    "serviceproblemid",
    "supplierid"
})
public class SERVICECODESUPPLIERID_Type {

    @XmlElement(name = "SERVICEPROBLEMID", required = true)
    protected SERVICEPROBLEMID_Type serviceproblemid;
    @XmlElement(name = "SUPPLIERID", required = true)
    protected SUPPLIERID_Type supplierid;

    /**
     * Gets the value of the serviceproblemid property.
     * 
     * @return
     *     possible object is
     *     {@link SERVICEPROBLEMID_Type }
     *     
     */
    public SERVICEPROBLEMID_Type getSERVICEPROBLEMID() {
        return serviceproblemid;
    }

    /**
     * Sets the value of the serviceproblemid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SERVICEPROBLEMID_Type }
     *     
     */
    public void setSERVICEPROBLEMID(SERVICEPROBLEMID_Type value) {
        this.serviceproblemid = value;
    }

    /**
     * Gets the value of the supplierid property.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getSUPPLIERID() {
        return supplierid;
    }

    /**
     * Sets the value of the supplierid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setSUPPLIERID(SUPPLIERID_Type value) {
        this.supplierid = value;
    }

}
